@@ -3,7 +3,7 @@
 //! version svd2rust 0.19.0 ( ))
 //!
 //! You can find an overview of the API here:
-//! [svd2rust/#peripheral-api](https://docs.rs/svd2rust/0.17.0/svd2rust/#peripheral-api)
+//! [svd2rust/#peripheral-api](https://docs.rs/svd2rust/0.19.0/svd2rust/#peripheral-api)
 //!
 
 #![deny(const_err)]
@@ -28,6 +28,15 @@
 mod generic;
 pub use self::generic::*;
 
+#[cfg(feature = "pic32mx1xxfxxxb")]
+pub mod pic32mx1xxfxxxb;
+
+#[cfg(feature = "pic32mx1xxfxxxc")]
+pub mod pic32mx1xxfxxxc;
+
+#[cfg(feature = "pic32mx1xxfxxxd")]
+pub mod pic32mx1xxfxxxd;
+
 #[cfg(feature = "pic32mx2xxfxxxb")]
 pub mod pic32mx2xxfxxxb;
 
@@ -36,3 +45,15 @@ pub mod pic32mx2xxfxxxc;
 
 #[cfg(feature = "pic32mx2xxfxxxd")]
 pub mod pic32mx2xxfxxxd;
+
+#[cfg(feature = "pic32mx1x4fxxxb")]
+pub mod pic32mx1x4fxxxb;
+
+#[cfg(feature = "pic32mx1x4fxxxd")]
+pub mod pic32mx1x4fxxxd;
+
+#[cfg(feature = "pic32mx2x4fxxxb")]
+pub mod pic32mx2x4fxxxb;
+
+#[cfg(feature = "pic32mx2x4fxxxd")]
+pub mod pic32mx2x4fxxxd;
